<?php

$lan = array(
  'Please indicate how often you want to receive messages' => 'Por favor, indique com que freq&uuml;&ecric;ncia voc&ecirc; quer receber as mensagens',
  'Email is blacklisted, so request for confirmation has been sent.' => 'O usu&aacute;rio est&aacute; na lista negra, ent&atilde; o pedido de confirma&ccedil;&atilde;o foi enviado.',
  'If user confirms subscription, they will be removed from the blacklist.' => 'Se o usu&aacute;rio confirmar a inscri&ccedil;&atilde;o, ele ser&aacute; removido da lista negra.',
//  'YouAreBlacklisted' => 'Seu email est&acute; em nossa "Lista Negra", o que significa que voc&ecirc; pediu para que n&atildeo; fossem enviados mais boletins. <br/>
//O &uacute;nico email que o sistema enviar&aacute; &eacute; a confirma&ccedil;&atilde;o e se voc&ecirc; clicar no link do email recebido, voc&ecirc; ser&aacute; removido de nossa lista negra e continuar&aacute; recendo os boletins.'
);

?>
